/*
 * include/version.h
 * Version number header file
 *
 * Copyright (c) 2017-2024 Roderick W. Smith
 *
 * Distributed under the terms of the GNU General Public License (GPL)
 * version 3 (GPLv3), a copy of which must be distributed with this
 * source code or binaries made from it.
 *
 */

#ifndef __VERSION_H
#define __VERSION_H

#define REFIND_VERSION L"0.14.2"

#endif
